@@ -1,4 +1,9 @@
 from text_explainability.global_explanation import (TokenFrequency, TokenInformation,
                                                     KMedoids, LabelwiseKMedoids, MMDCritic, LabelwiseMMDCritic)
 from text_explainability.local_explanation import LIME, KernelSHAP, Anchor, LocalTree
-from text_explainability.utils import default_tokenizer, default_detokenizer
+from text_explainability.utils import (default_tokenizer, default_detokenizer,
+                                       word_tokenizer, word_detokenizer,
+                                       character_tokenizer, character_detokenizer)
+
+
+__version__ = '0.4.4'
